@@ -75,7 +75,11 @@ int WRun(int argc, char *argv[], ApplicationCreator createApplication)
 }
  * \endcode
  */
+#ifdef WT_WIN32
 class WServer
+#else // WT_WIN32
+class WTCONNECTOR_API WServer
+#endif // WT_WIN32
 {
 public:
   typedef std::function<std::string (std::size_t max_length, int purpose)>
@@ -142,6 +146,30 @@ public:
   WTCONNECTOR_API
     WServer(int argc, char *argv[], const std::string& wtConfigurationFile = std::string());
 
+  /*! \brief Creates a new server instance and configures it.
+   *
+   * This is equivalent to:
+   * \code
+    WServer server(applicationPath);
+    server.setServerConfiguration(applicationPath, args, wtConfigurationFile);
+    \endcode
+   *
+   * This version of the WServer constructor takes a std::string
+   * for the application path, and a vector of arguments (not including
+   * argv[0], the application path) instead of argc and argv,
+   * for better convenience when arguments are not provided via
+   * the command line.
+   *
+   * \throws Exception : indicates a configuration problem.
+   *
+   * \sa WServer(const std::string&, const std::string&)
+   * \sa setServerConfiguration()
+   */
+  WTCONNECTOR_API
+    WServer(const std::string &applicationPath,
+            const std::vector<std::string> &args,
+            const std::string& wtConfigurationFile = std::string());
+
   /*! \brief Destructor.
    *
    * If the server was still running, it is stopped first by calling
@@ -209,16 +237,49 @@ public:
 				const std::string& serverConfigurationFile
 				= std::string());
 
+  /*! \brief Configures the HTTP(S) server or FastCGI process.
+   *
+   * Configures the HTTP(S) server using command-line arguments, a
+   * configuration file, or both. The valid options are described in
+   * \ref config_wthttpd "Built-in httpd configuration".
+   *
+   * The applications themselves are configured using the configuration
+   * file passed to the constructor.
+   *
+   * The server configuration must be set before any other
+   * functionality can be used.
+   *
+   * In case of FastCGI deployment, the \p serverConfigurationFile
+   * argument is ignored, and depending on the command-line arguments,
+   * this process may become a FastCGI protocol relay process which
+   * never returning from this call but directs the FastCGI stream to
+   * the correct session, rather than a Wt application server.
+   *
+   * This version of setServerConfiguration() takes a std::string
+   * for the application path, and a vector of arguments (not including
+   * argv[0], the application path) instead of argc and argv,
+   * for better convenience when arguments are not provided via
+   * the command line.
+   *
+   * \throws Exception : indicates a configuration problem.
+   */
+  WTCONNECTOR_API
+    void setServerConfiguration(const std::string &applicationPath,
+                                const std::vector<std::string> &args,
+                                const std::string &serverConfigurationFile = std::string());
+
   /*! \brief Binds an entry-point to a callback function to create
    *         a new application.
    *
    * The \p path is the local URL at which the application is
    * deployed: when a user visits this URL, the callback will be
-   * called to create a new application. If empty, the URL is inferred
-   * from the server configuration's deploy-path (see also \ref
-   * config_wthttpd "Built-in httpd configuration").
+   * called to create a new application.
    *
-   * The path must start with a '/'.
+   * If the \p path does not start with a slash ('/'), the deployment path
+   * will be prepended. The deployment path defaults to '/' but can be overridden
+   * in the wthttp connector with the --deploy-path option (see also \ref
+   * config_wthttpd "Built-in httpd configuration"). This implies that when
+   * the \p path is empty (the default), it is set to the deployment path.
    *
    * The optional \p favicon is a URL path (which should not
    * contain the host part!) to a favicon, which is the icon displayed
@@ -335,6 +396,20 @@ public:
    */
   WT_API static void restart(int argc, char **argv, char **envp);
 
+  /*! \brief A utility method to restart.
+   *
+   * This will result the application with the new image (applicationPath), effectively
+   * loading a newly deployed version. <i>(Experimental, UNIX only)</i>
+   *
+   * This version of restart() takes a std::string
+   * for the application path, and a vector of arguments (not including
+   * argv[0], the application path) instead of argc and argv,
+   * for better convenience when arguments are not provided via
+   * the command line.
+   */
+  WT_API static void restart(const std::string &applicationPath,
+                             const std::vector<std::string> &args);
+
   /*! \brief Returns the server HTTP port number.
    *
    * Returns -1 if the port is not known (i.e. because the connector is
@@ -543,6 +618,8 @@ private:
 	           const std::string& configurationFile);
   WT_API void destroy();
   WT_API void setCatchSignals(bool catchSignals);
+  WT_API std::string prependDefaultPath(const std::string& path);
+
 
   WT_API static WServer *instance_;
   std::function<std::string (std::size_t max_length, int purpose)> sslPasswordCallback_;
