@@ -25,9 +25,8 @@ enum class TemplateWidgetIdMode {
   None,
 
   /*!
-   * Use setObjectName() to prefix the ID with the varName. This is
-   * a safe choice since %Wt still guarantees that the IDs are
-   * unique.
+   * Use setObjectName() to add a 'data-object-name' attribute. This is
+   * a safe choice since it does not affect the ID.
    */
   SetObjectName,
 
@@ -95,7 +94,7 @@ enum class TemplateWidgetIdMode {
  *
  * <tt>${var arg1="A value" arg2='A second value'}</tt>
  *
- * The arguments can thus be simple simple strings or quoted strings
+ * The arguments can thus be simple strings or quoted strings
  * (single or double quoted). These arguments are applied to a
  * resolved widget in applyArguments() and currently supports only
  * style classes.
@@ -104,7 +103,7 @@ enum class TemplateWidgetIdMode {
  * bindString() or bindInt() or by reimplementing the resolveString()
  * and resolveWidget() methods.
  *
- * \note The use of XML comments (<tt>&lt;!-- ... --&gt;</tt>)
+ * \note The use of XML comments (<tt>&lt;!\-- ... \--&gt;</tt>)
  *       around variables that are bound to widgets will result in bad
  *       behaviour since the template parser is ignorant about these
  *       comments and the corresponding widgets will believe that they
@@ -317,6 +316,9 @@ public:
      *
      * The function will consider the first argument as the condition, and the
      * second argument as the key for a localized string that is a macro block.
+     *
+     * Just like the block() function, you can provide additional arguments, so the third
+     * argument will be what is filled in into <tt>{1}</tt> in the macro block, etc.
      */
 #ifndef WT_TARGET_JAVA
     static bool while_f(WTemplate *t, const std::vector<WString>& args,
@@ -395,10 +397,10 @@ public:
   /*! \brief Sets how the varName should be reflected on bound widgets.
    *
    * To easily identify a widget in the browser, it may be convenient
-   * to reflect the varName to the widget's ID. This options allows
-   * you to choose from two methods.
+   * to reflect the varName, either through the object name (recommended)
+   * or the widget's ID.
    *
-   * The default value is SetNoWidgetId which does not reflect the
+   * The default value is TemplateWidgetIdMode::None which does not reflect the
    * varName on the bound widget.
    */
   void setWidgetIdMode(TemplateWidgetIdMode mode);
@@ -467,11 +469,42 @@ public:
   template <typename Widget>
     Widget *bindWidget(const std::string& varName,
                        std::unique_ptr<Widget> widget)
+#ifndef WT_TARGET_JAVA
   {
     Widget *result = widget.get();
     bindWidget(varName, std::unique_ptr<WWidget>(std::move(widget)));
     return result;
   }
+#else // WT_TARGET_JAVA
+  ;
+#endif // WT_TARGET_JAVA
+
+#ifndef WT_TARGET_JAVA
+  /*! \brief Creates a new widget with the given arguments, and binds it, returning a raw pointer.
+   *
+   * This is implemented as:
+   *
+   * \code
+   * std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
+   * Widget *result = w.get();
+   * bindWidget(varName, std::unique_ptr<WWidget>(std::move(w)));
+   * return result;
+   * \endcode
+   *
+   * This is a useful shorthand for creating and binding a widget in one go.
+   */
+  template <typename Widget, typename ...Args>
+    Widget *bindNew(const std::string& varName,
+	            Args&& ...args)
+  {
+    std::unique_ptr<Widget> w{new Widget(std::forward<Args>(args)...)};
+    Widget *result = w.get();
+    bindWidget(varName, std::unique_ptr<WWidget>(std::move(w)));
+    return result;
+  }
+#endif // WT_TARGET_JAVA
+
+  using WWidget::removeWidget;
 
   /*! \brief Unbinds a widget by variable name.
    *
@@ -660,9 +693,11 @@ public:
 
   /*! \brief Returns a widget for a variable name.
    *
-   * This is a convience method, which calls resolveWidget() and casts
+   * This is a convience method, which calls resolveWidget() and dynamic casts
    * the result to type \p T. You may use this method to fetch widgets
    * that have previously been bound using bindWidget().
+   *
+   * If the cast fails, a null pointer is returned.
    */
   template <typename T> T resolve(const std::string& varName);
 
@@ -791,7 +826,7 @@ protected:
 private:
   typedef std::map<std::string, Function> FunctionMap;
   typedef std::map<std::string, WString> StringMap;
-  typedef std::map<std::string, std::unique_ptr<WWidget>> WidgetMap;
+  typedef std::map<std::string, std::unique_ptr<WWidget> > WidgetMap;
   typedef std::set<std::string> ConditionSet;
 
   std::set<WWidget *> *previouslyRendered_;
